==> ustreamer_4.9.orig.tar.gz: ustreamer-4.9/tools/common.py <==
#!/usr/bin/env python3
# ========================================================================== #
#                                                                            #
#    uStreamer - Lightweight and fast MJPG-HTTP streamer.                    #
#                                                                            #
#    Copyright (C) 2018-2021  Maxim Devaev <mdevaev@gmail.com>               #
#                                                                            #
#    This program is free software: you can redistribute it and/or modify    #
#    it under the terms of the GNU General Public License as published by    #
#    the Free Software Foundation, either version 3 of the License, or       #
#    (at your option) any later version.                                     #
#                                                                            #
#    This program is distributed in the hope that it will be useful,         #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
#    GNU General Public License for more details.                            #
#                                                                            #
#    You should have received a copy of the GNU General Public License       #
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.  #
#                                                                            #
# ========================================================================== #


import textwrap


# =====
C_PREPEND = textwrap.dedent("""
        /*****************************************************************************
        #                                                                            #
        #    uStreamer - Lightweight and fast MJPG-HTTP streamer.                    #
        #                                                                            #
        #    Copyright (C) 2018-2021  Maxim Devaev <mdevaev@gmail.com>               #
        #                                                                            #
        #    This program is free software: you can redistribute it and/or modify    #
        #    it under the terms of the GNU General Public License as published by    #
        #    the Free Software Foundation, either version 3 of the License, or       #
        #    (at your option) any later version.                                     #
        #                                                                            #
        #    This program is distributed in the hope that it will be useful,         #
        #    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
        #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
        #    GNU General Public License for more details.                            #
        #                                                                            #
        #    You should have received a copy of the GNU General Public License       #
        #    along with this program.  If not, see <https://www.gnu.org/licenses/>.  #
        #                                                                            #
        *****************************************************************************/


    """).strip() + "\n"

==> ustreamer_5.4.orig.tar.gz: ustreamer-5.4/tools/common.py <==
#!/usr/bin/env python3
# ========================================================================== #
#                                                                            #
#    uStreamer - Lightweight and fast MJPEG-HTTP streamer.                   #
#                                                                            #
#    Copyright (C) 2018-2022  Maxim Devaev <mdevaev@gmail.com>               #
#                                                                            #
#    This program is free software: you can redistribute it and/or modify    #
#    it under the terms of the GNU General Public License as published by    #
#    the Free Software Foundation, either version 3 of the License, or       #
#    (at your option) any later version.                                     #
#                                                                            #
#    This program is distributed in the hope that it will be useful,         #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
#    GNU General Public License for more details.                            #
#                                                                            #
#    You should have received a copy of the GNU General Public License       #
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.  #
#                                                                            #
# ========================================================================== #


import textwrap


# =====
C_PREPEND = textwrap.dedent("""
        /*****************************************************************************
        #                                                                            #
        #    uStreamer - Lightweight and fast MJPEG-HTTP streamer.                   #
        #                                                                            #
        #    Copyright (C) 2018-2022  Maxim Devaev <mdevaev@gmail.com>               #
        #                                                                            #
        #    This program is free software: you can redistribute it and/or modify    #
        #    it under the terms of the GNU General Public License as published by    #
        #    the Free Software Foundation, either version 3 of the License, or       #
        #    (at your option) any later version.                                     #
        #                                                                            #
        #    This program is distributed in the hope that it will be useful,         #
        #    but WITHOUT ANY WARRANTY; without even the implied warranty of          #
        #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           #
        #    GNU General Public License for more details.                            #
        #                                                                            #
        #    You should have received a copy of the GNU General Public License       #
        #    along with this program.  If not, see <https://www.gnu.org/licenses/>.  #
        #                                                                            #
        *****************************************************************************/


    """).strip() + "\n"
